==> glog-2.70.tar.gz: glog-2.70/lib/html.php <==
<?php
# HTML functions
#
# $Id: html.php,v 1.4 2005/05/27 18:55:38 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	if (LIB_INCLUDE != 1)
		exit;

	/*   XHTML  */
	function html_begin($title="", $diary_link=true, $noindex=false) {
		if ($title == "")
			$title = BLOG_TITLE;
		else
			$title = BLOG_TITLE . " / " . $title;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
	<meta http-equiv="content-type" content="text/html; charset=windows-1251" />
	<meta name="author" content="<?=AUTHOR_NAME?>" />
	<meta name="generator" content="gf's blog" />
<?	if ($noindex) { ?>
	<meta name="robots" content="noindex,noarchive" />
<?	} ?>
	<link href="<?=BASEDIR?>css/diary.css" rel="stylesheet" type="text/css" />
	<link rel="alternate stylesheet" title="Black" href="<?=BASEDIR?>css/diary_black.css" />
	<link rel="alternate stylesheet" title="Blue" href="<?=BASEDIR?>css/diary_blue.css" />
	<link rel="alternate stylesheet" title="Orange" href="<?=BASEDIR?>css/diary_orange.css" />
	<link rel="alternate" type="application/rss+xml" title="<?=$title?> RSS" href="<?=BASEDIR?>index.xml.php" />
	<link rel="SHORTCUT ICON" href="<?=BASEDIR?>favicon.png" />
	<title><?=$title?></title>
</head>
<body>
<a name="top"></a>

<?	if (BASEDIR != "/") { ?>
<a href="/">&lt; HomePage</a>
<?	} ?>
<div id="spacer">
<?		if ($diary_link) { ?>
<a href="<?=BASEDIR?>">&lt;- </a><br />
<?		}
	}

	/*   XHTML , ,    */
	function html_end() {
?>
</div>

<div align="right">
<a href="http://www.nosoftwarepatents.org/"><img src="<?=BASEDIR?>images/patent_button.png" height="99" width="101" alt="No e-patents" title="No e-patents" border="0" /></a>

<a href="http://validator.w3.org/check/referer"><img border="0" src="<?=BASEDIR?>images/valid-xhtml10.png" alt="Valid XHTML 1.0!" height="31" width="88" title="Validate my HTML" /></a>
<a href="http://jigsaw.w3.org/css-validator/validator?uri=http://<?=$_SERVER['SERVER_NAME']?><?=BASEDIR?>css/diary.css"><img border="0" width="88" height="31" style="border:0;width:88px;height:31px" src="<?=BASEDIR?>images/vcss.png" alt="Valid CSS!" title="Validate my CSS" /></a>

<!-- Creative Commons License -->
<a rel="license" href="http://creativecommons.org/licenses/by-nc-sa/2.0/"><img alt="Creative Commons License" border="0" src="<?=BASEDIR?>images/somerights.gif" width="88" height="31" title="Read more about Creative Commons" /></a>
<!-- /Creative Commons License -->

<!--

<rdf:RDF xmlns="http://web.resource.org/cc/"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#">
<Work rdf:about="">
   <dc:type rdf:resource="http://purl.org/dc/dcmitype/Text" />
   <license rdf:resource="http://creativecommons.org/licenses/by-nc-sa/2.0/" />
</Work>

<License rdf:about="http://creativecommons.org/licenses/by-nc-sa/2.0/">
   <permits rdf:resource="http://web.resource.org/cc/Reproduction" />
   <permits rdf:resource="http://web.resource.org/cc/Distribution" />
   <requires rdf:resource="http://web.resource.org/cc/Notice" />
   <requires rdf:resource="http://web.resource.org/cc/Attribution" />
   <prohibits rdf:resource="http://web.resource.org/cc/CommercialUse" />
   <permits rdf:resource="http://web.resource.org/cc/DerivativeWorks" />
   <requires rdf:resource="http://web.resource.org/cc/ShareAlike" />
</License>

</rdf:RDF>

-->
</div>

</body>
</html>
<?
	}
?>

==> glog-3.00.tar.gz: glog-3.00/lib/html.php <==
<?php
# HTML functions
#
# $Id: html.php,v 1.8 2005/08/19 13:21:14 gf Exp $
#
# Copyright (c) 2004 Georgi Chorbadzhiyski
# All rights reserved.
#
# Redistribution and use of this script, with or without modification, is
# permitted provided that the following conditions are met:
#
# 1. Redistributions of this script must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
#
#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR IMPLIED
#  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
#  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.  IN NO
#  EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
#  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
#  PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
#  OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
#  WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
#  OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
#  ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#
	if (LIB_INCLUDE != 1)
		exit;

	/*   XHTML  */
	function html_begin($title="", $diary_link=true, $noindex=false) {
		if ($title == "")
			$title = BLOG_TITLE;
		if ($title != BLOG_TITLE)
			$title = BLOG_TITLE . " / " . $title;
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
    "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html>
<head>
	<meta http-equiv="content-type" content="text/html; charset=windows-1251" />
	<meta name="author" content="<?=AUTHOR_NAME?>" />
	<meta name="generator" content="Glog! <?=VERSION?>" />
<?	if ($noindex) { ?>
	<meta name="robots" content="noindex,noarchive" />
<?	} ?>
	<link href="<?=BASEDIR?>css/diary.css" rel="stylesheet" type="text/css" />
	<link rel="alternate stylesheet" title="Black" href="<?=BASEDIR?>css/diary_black.css" />
	<link rel="alternate stylesheet" title="Blue" href="<?=BASEDIR?>css/diary_blue.css" />
	<link rel="alternate stylesheet" title="Orange" href="<?=BASEDIR?>css/diary_orange.css" />
	<link rel="alternate" type="application/rss+xml" title="<?=BLOG_TITLE?> RSS 2.0" href="<?=BASEDIR?>index.rss.php" />
	<link rel="alternate" type="application/rss+xml" title="<?=BLOG_TITLE?> RSS 2.0 Comments" href="<?=BASEDIR?>comments.rss.php" />
	<link rel="alternate" type="application/atom+xml" title="<?=BLOG_TITLE?> Atom 0.3" href="<?=BASEDIR?>index.atom.php" />
	<link rel="alternate" type="application/rdf+xml" title="<?=BLOG_TITLE?> RDF" href="<?=BASEDIR?>index.rdf.php" />
	<link rel="SHORTCUT ICON" href="<?=BASEDIR?>favicon.png" />
	<title><?=$title?></title>
</head>
<body>
<a name="top"></a>

<?	if (BASEDIR != "/") { ?>
<a href="/">&lt; HomePage</a>
<?	} ?>
<div id="spacer">
<?		if ($diary_link) { ?>
<a href="<?=BASEDIR?>">&lt;- </a><br />
<?		}
	}

	/*   XHTML , ,    */
	function html_end() {
?>
</div>

<?
	include("copyright.php");
?>

<div id="buttons">
<!-- <a href="http://www.nosoftwarepatents.org/"><img src="<?=BASEDIR?>images/patent_button.png" height="99" width="101" alt="No e-patents" title="No e-patents" border="0" /></a> -->
<a href="http://validator.w3.org/check/referer"><img border="0" src="<?=BASEDIR?>images/valid-xhtml10.png" alt="Valid XHTML 1.0!" height="31" width="88" title="Validate my HTML" /></a>
<a href="http://jigsaw.w3.org/css-validator/validator?uri=http://<?=$_SERVER['SERVER_NAME']?><?=BASEDIR?>css/diary.css"><img border="0" width="88" height="31" style="border:0;width:88px;height:31px" src="<?=BASEDIR?>images/vcss.png" alt="Valid CSS!" title="Validate my CSS" /></a>
</div>

</body>
</html>
<?
	}
?>
